CustomEmojisEndpoint: R6 Class for Custom Emojis Endpoint

CustomEmojisEndpointR Documentation

R6 Class for Custom Emojis Endpoint

Description

Handle all custom emojis operations in the Notion API

Note: Access this endpoint through the client instance, e.g., notion$custom_emojis. Not to be instantiated directly.

Value

A list containing the parsed API response.

Methods

Public methods


Method new()

Initialise custom emojis endpoint. Not to be called directly, e.g., use notion$custom_emojis instead.

Usage
CustomEmojisEndpoint$new(client)
Arguments
client

Notion Client instance


Method list()

List custom emojis

Usage
CustomEmojisEndpoint$list(start_cursor = NULL, page_size = NULL, name = NULL)
Arguments
start_cursor

Character. For pagination. If provided, returns results starting from this cursor. If NULL, returns the first page of results.

page_size

Integer. Number of items to return per page (1-100). Defaults to 100

name

Character. Filters custom emojis by exact name match. Useful for resolving a custom emoji name to its ID.

Details

Endpoint documentation

Examples


notion <- notion_client()

notion$custom_emojis$list()



notionapi documentation built on April 13, 2026, 9:07 a.m.