no_config: Create empty property configuration

View source: R/utils.R

no_configR Documentation

Create empty property configuration

Description

Helper function that creates an empty named list for property configurations that require no additional settings.

Many database properties like text, checkbox and date do not need configuration settings. This function returns the empty configuration ({} in JSON) that these properties expect.

Usage

no_config()

Value

An empty ⁠named list⁠ that serialises to {} in JSON

Examples


notion <- notion_client()

# ----- Create a data source
notion$data_sources$create(
  list(
    database_id = "5f9759b2-ad71-4b66-880f-d0306614227b"
  ),
  properties = list(
    Title = list(
      title = no_config()
    )
  ),
  title = list(list(
    text = list(
      content = "Test data source"
    )
  ))
)



notionapi documentation built on April 13, 2026, 9:07 a.m.