Skip to contents

Handle all custom emojis operations in the Notion API

Note: Access this endpoint through the client instance, e.g., notion$custom_emojis. Not to be instantiated directly.

Value

A list containing the parsed API response.

Methods


Method new()

Initialise custom emojis endpoint. Not to be called directly, e.g., use notion$custom_emojis instead.

Usage

Arguments

client

Notion Client instance


Method list()

List custom emojis

Usage

CustomEmojisEndpoint$list(start_cursor = NULL, page_size = NULL, name = NULL)

Arguments

start_cursor

Character. For pagination. If provided, returns results starting from this cursor. If NULL, returns the first page of results.

page_size

Integer. Number of items to return per page (1-100). Defaults to 100

name

Character. Filters custom emojis by exact name match. Useful for resolving a custom emoji name to its ID.

Examples

notion <- notion_client()
notion$custom_emojis$list()
#> {
#>   "object": "list",
#>   "type": "custom_emoji",
#>   "results": [],
#>   "has_more": false,
#>   "next_cursor": {},
#>   "request_id": "57a6f7d8-700e-4018-ade9-6b7f37736f5a"
#> }