| CustomEmojisEndpoint | R Documentation |
Handle all custom emojis operations in the Notion API
Note: Access this endpoint through the client instance, e.g., notion$custom_emojis. Not to be instantiated directly.
A list containing the parsed API response.
new()Initialise custom emojis endpoint.
Not to be called directly, e.g., use notion$custom_emojis instead.
CustomEmojisEndpoint$new(client)
clientNotion Client instance
list()List custom emojis
CustomEmojisEndpoint$list(start_cursor = NULL, page_size = NULL, name = NULL)
start_cursorCharacter. For pagination. If provided, returns results starting from this cursor. If NULL, returns the first page of results.
page_sizeInteger. Number of items to return per page (1-100). Defaults to 100
nameCharacter. Filters custom emojis by exact name match. Useful for resolving a custom emoji name to its ID.
notion <- notion_client()
notion$custom_emojis$list()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.